@@ -1,5 +1,6 @@
 package Mojolicious::Plugin::AssetPack::Pipe::JavaScript;
 use Mojo::Base 'Mojolicious::Plugin::AssetPack::Pipe';
+
 use Mojolicious::Plugin::AssetPack::Util qw(diag load_module DEBUG);
 
 sub process {
@@ -8,21 +9,19 @@ sub process {
   my $file;
 
   return unless $self->assetpack->minify;
-  return $assets->each(
-    sub {
-      my ($asset, $index) = @_;
-      my $attrs = $asset->TO_JSON;
-      $attrs->{key}      = 'js-min';
-      $attrs->{minified} = 1;
-      return if $asset->format ne 'js' or $asset->minified;
-      return $asset->content($file)->minified(1) if $file = $store->load($attrs);
-      return unless length(my $js = $asset->content);
-      load_module 'JavaScript::Minifier::XS';
-      diag 'Minify "%s" with checksum %s.', $asset->url, $asset->checksum if DEBUG;
-      $js = JavaScript::Minifier::XS::minify($js);
-      $asset->content($store->save(\$js, $attrs))->minified(1);
-    }
-  );
+  return $assets->each(sub {
+    my ($asset, $index) = @_;
+    my $attrs = $asset->TO_JSON;
+    $attrs->{key}      = 'js-min';
+    $attrs->{minified} = 1;
+    return if $asset->format ne 'js' or $asset->minified;
+    return $asset->content($file)->minified(1) if $file = $store->load($attrs);
+    return unless length(my $js = $asset->content);
+    load_module 'JavaScript::Minifier::XS';
+    diag 'Minify "%s" with checksum %s.', $asset->url, $asset->checksum if DEBUG;
+    $js = JavaScript::Minifier::XS::minify($js);
+    $asset->content($store->save(\$js, $attrs))->minified(1);
+  });
 }
 
 1;
